@@ -58,7 +58,7 @@ AnyEvent::TLS::SNI - Adds Server Name Indication (SNI) support to AnyEvent::TLS
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -81,6 +81,26 @@ version 0.02
     );
     $cv->recv;
 
+=head1 NAME
+
+AnyEvent::TLS::SNI - Adds Server Name Indication (SNI) support to AnyEvent::TLS client.
+This module IS DEPRECATED, AnyEvent 7.12 has SNI support. 
+
+=head1 VERSION
+
+version 0.02
+
+=head1 AUTHOR
+
+Alexander Nalobin <alexander@nalobin.ru>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Alexander Nalobin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 AUTHOR
 
 Alexander Nalobin <alexander@nalobin.ru>
